API
===

Tokenizer
---------

.. toctree::
   :maxdepth: 1

   descope.tokenizer

Dataset
--------

.. toctree::
   :maxdepth: 1

   descope.dataset

Trainer
-------

.. toctree::
   :maxdepth: 1

   descope.trainer

Inference
---------

.. toctree::
   :maxdepth: 1

   descope.inference

Utils
-----

.. toctree::
   :maxdepth: 1

   descope.utils

Logging
-------

.. toctree::
   :maxdepth: 1

   descope.logging

Arguments
---------

.. toctree::
   :maxdepth: 1

   descope.arguments